AnimationManager class

Constructors

AnimationManager(List<AbsAnimationGroup> groups)

Properties

duration Duration
getter/setter pair
groups List<AbsAnimationGroup>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
matrix4 Matrix4
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculateMatrix(double millTime) Matrix4
isReverse(bool reverse) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited