AnimationPart class

Constructors

AnimationPart({required int moment, Curve curve = Curves.linear, double x = 1.0, double y = 1.0, double z = 1.0})

Properties

curve Curve
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
moment int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xyz ↔ Vector3
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited